# Generated by Django 2.2.4 on 2019-08-06 15:16

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import people.models.person.person


class Migration(migrations.Migration):

    dependencies = [
        ('people', '0002_auto_20190805_1713'),
    ]

    operations = [
        migrations.AlterField(
            model_name='person',
            name='auth_user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='person', to=settings.AUTH_USER_MODEL, verbose_name='User'),
        ),
        migrations.AlterField(
            model_name='person',
            name='curriculum_vitae',
            field=models.FileField(blank=True, help_text='This field will appear in the website.', null=True, upload_to=people.models.person.person.get_cv_upload_path, verbose_name='Short Vitae'),
        ),
        migrations.AlterField(
            model_name='person',
            name='img',
            field=models.ImageField(blank=True, help_text='This field will appear in the website.', max_length=150, upload_to=people.models.person.person.get_image_upload_path, verbose_name='Picture'),
        ),
    ]
