from .person.person import Person
from .person.institution_affiliation import InstitutionAffiliation
from .person.academic_career import AcademicCareer
from .person.degree import Degree
from .person.scientific_area import ScientificArea

from .group.group_type import GroupType
from .group.group import Group
from .group.position import Position
from .group.group_membership import GroupMembership
