# Generated by Django 2.2.4 on 2019-08-23 13:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('people', '0004_auto_20190806_1713'),
    ]

    operations = [
        migrations.AlterField(
            model_name='person',
            name='email',
            field=models.EmailField(help_text='This field will appear in the website.', max_length=254, unique=True, verbose_name='Research email'),
        ),
        migrations.AlterField(
            model_name='person',
            name='personal_email',
            field=models.EmailField(blank=True, max_length=254, null=True, unique=True, verbose_name='Personal email'),
        ),
    ]
